@@ -22,7 +22,7 @@ disc.mle <- function(x, distr = "poisson", N = NULL, type = 1, tol = 1e-07) {
   } else if ( distr == "gammapois" ) {
     res <- Rfast2::gammapois.mle(x, tol = tol)
   } else if ( distr == "skellam" ) {
-    res <- skellam::skellam.mle(x)
+    res <- .skellam.mle(x)
   } else if ( distr == "gp" ) {
     res <- gp::gp.mle(x)
   } else if( distr == "cc" ) {
@@ -45,3 +45,26 @@ disc.mle <- function(x, distr = "poisson", N = NULL, type = 1, tol = 1e-07) {
 
   res
 }
+
+
+
+.skellam.mle <- function(x) {
+
+  n <- length(x)
+  sx <- sum(x)
+  sx2 <- sx / 2
+  mx <- sx / n
+  theta <- stats::var(x)/2  - mx/2
+
+  skel <- function(theta) {
+    a <- 2 * sqrt(theta^2 + theta * mx)
+    n * 2 * theta + sx - sx2 * log(1 + mx / theta) -
+    sum( log( besselI(a, x, expon.scaled = TRUE) ) ) - n * a
+  }
+
+  mod <- optim(theta, skel, control = list(maxit = 5000) )
+  param <- c( mod$par + mx, mod$par )
+  names(param) <- c("mu 1", "mu 2")
+  list(param = param, loglik = -mod$value)
+
+}
